# 🌐 `@geo watch`

watch the planet's story unfold.

```bash
@geo watch help
```
--help-- blue_geo watch

🎯 [`geo-watch-targets/metadata.yaml`](https://kamangir-public.s3.ca-central-1.amazonaws.com/geo-watch-targets/metadata.yaml).

## example run

```bash
@geo watch \
  batch \
  target=elkhema-2024 \
  to=aws_batch \
  modality=rgb \
  publish \
  geo-watch-elkhema-2024-2024-10-05-a-b
```

[dev notes](https://arash-kamangir.medium.com/%EF%B8%8F-conversations-with-ai-252-2118326b1de2).

--scale-note--

--table--
